@@ -1,9 +1,9 @@
 #define _GNU_SOURCE
 
-#include "append_list.h"	// inline
-#include "compare_verify_one.h"	// inline
-#include "create_symboliclink.h"	// inline
-#include "print_error.h"	// inline
+#include "append_list.h"
+#include "compare_verify_one.h"
+#include "create_symboliclink.h"
+#include "print_error.h"
 #include "read_write.h"
 #include "remove_source_rmdir.h"
 #include "remove_source_unlink.h"
@@ -13,8 +13,7 @@
 #include "struct_OPArg.h"
 #include "struct_RData.h"
 #include "struct_SDir.h"
-#include "xmalloc.h"	// inline
-#include "xmalloc0.h"	// inline
+#include "xmalloc.h"
 
 #include <limits.h>
 #include <stdbool.h>
@@ -29,36 +28,47 @@
 
 /* 関数プロトタイプ */
 RData * check_target(const OPArg *, const VList *drive_list, const SDir *);
-static inline VList * link_copy(const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
-static inline VList * file_copy(const VList *drive_list, const char src[], const char dst[], const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
-static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
-static inline void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
-static inline void write_file_or_create_link(const OPArg *, const SDir *, CPInfo *, CPDD *);
-static inline _Bool this_dir_check(const CPInfo *cpinfo, const char *this_dir);
+static inline VList * copy_arg_link(const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static inline VList * copy_arg_file(const VList *drive_list, const char src[], const char dst[], const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
+static void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
+static void check_write_file_or_create_link(const OPArg *, const SDir *, CPInfo *, CPDD *);
+static inline _Bool check_this_dir(const CPInfo *cpinfo, const char *this_dir);
 static inline struct stat * make_directory(const OPArg *, CPInfo *, CPDD *);
 static VList * dir_traverse(const OPArg *, const SDir *, VList *file_list, CPInfo *, CPDD *);
 static inline void delete_last_slash(const int len, char []);
-static inline CPInfo * cpinfo_malloc(void);
+static inline CPInfo * malloc_cpinfo(void);
 static inline char * get_dst_plus_srcname(const char *src, const char *dst);
-static inline void count_link_plus(CPInfo *, CPDD *);
-static inline void count_file_plus(CPInfo *, CPDD *);
-static inline void count_dire_plus(CPInfo *, CPDD *);
+static inline void count_plus_link(CPInfo *, CPDD *);
+static inline void count_plus_file(CPInfo *, CPDD *);
+static inline void count_plus_dir(CPInfo *, CPDD *);
 static inline void ch_time_and_mod_dir(const CPInfo *, const struct stat *, CPDD *);
 static inline void clean(const char buf[], const int len);
 static inline void fgets_is_null(void);
-static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
+static inline void check_set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
 
 /*******************************************************************************
 *******************************************************************************/
 RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sdir)
 {
+	int loop_dst = oparg->dst_index;
+
+	if(g_file_test(oparg->argv[loop_dst], G_FILE_TEST_IS_SYMLINK) == TRUE)
+	{
+		fprintf(stderr, "コピー先がシンボリックリンクです\n");
+		exit(EXIT_FAILURE);
+	}
+
 	enum argument_count
 	{
 		SINGULAR,
 		PLURAL,
 	} acount;
 
-	VList *file_list = NULL;
+	int loop = oparg->src_index;
+
+	/* 三項演算子 */
+	((loop_dst - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
 	/*
 	 * CPDD *cpdd = xmalloc0(sizeof(CPDD));
@@ -78,22 +88,6 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 	cpdd->total_error = 0;
 	cpdd->thread_mode_count = 0;
 
-	char tmp_src[PATH_MAX];
-	char tmp_dst[PATH_MAX];
-	int loop = oparg->src_index;
-	int loop_dst = oparg->dst_index;
-
-	_Bool file_found = false;
-
-	if(g_file_test(oparg->argv[loop_dst], G_FILE_TEST_IS_SYMLINK) == TRUE)
-	{
-		fprintf(stderr, "コピー先がシンボリックリンクです\n");
-		exit(EXIT_FAILURE);
-	}
-
-	/* 三項演算子 */
-	((loop_dst - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
-
 	/* コピー元が単一かつ . で、コピー先が存在しないとき用の処理 */
 	{
 		char *s = oparg->argv[loop];
@@ -110,8 +104,14 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				if(*s == t)
 				{
 					s++;
-					if(t == '.') { t = G_DIR_SEPARATOR; }
-					else { t = '.'; }
+					if(t == '.')
+					{
+						t = G_DIR_SEPARATOR;
+					}
+					else
+					{
+						t = '.';
+					}
 				}
 				else if(*s == '\0')
 				{
@@ -142,6 +142,8 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		}
 	}
 
+	char tmp_dst[PATH_MAX];
+	_Bool file_found = false;
 	errno = 0;
 	realpath(oparg->argv[loop_dst], tmp_dst);
 
@@ -155,6 +157,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		int dlen = strlen(d);
 		char *c;
 
+		/* 末尾がパス区切り文字の場合はヌル文字に変えておく */
 		if(d[dlen - 1] == G_DIR_SEPARATOR)
 		{
 			char *z = xmalloc(dlen + 1);
@@ -187,6 +190,8 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		exit(EXIT_FAILURE);
 	}
 
+	VList *file_list = NULL;
+	char tmp_src[PATH_MAX];
 	int len_dst = strlen(tmp_dst);
 	delete_last_slash(len_dst, tmp_dst);
 
@@ -233,10 +238,10 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		int len_src = strlen(tmp_src);
 		delete_last_slash(len_src, tmp_src);
 
-		CPInfo *cpinfo = cpinfo_malloc();
+		CPInfo *cpinfo = malloc_cpinfo();
 
 		len_src++;
-		cpinfo->src = xmalloc(len_src);
+		cpinfo->src = xmalloc_inline(len_src);
 		memcpy(cpinfo->src, tmp_src, len_src);
 		len_src--;
 
@@ -260,7 +265,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 					{
-						file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
+						file_list = copy_arg_file(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 					{
@@ -283,17 +288,18 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 			else if(g_file_test(tmp_dst, G_FILE_TEST_IS_DIR) == TRUE)
 			{
 				cpinfo->dst = get_dst_plus_srcname(tmp_src, tmp_dst);
+
 				if(link_flag == true)
 				{
-					file_list = link_copy(oparg, sdir, cpinfo, cpdd, file_list);
+					file_list = copy_arg_link(oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 				{
-					file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
+					file_list = copy_arg_file(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 				{
-					file_list = dir_copy(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
+					file_list = copy_arg_dir(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
 				}
 				else
 				{
@@ -310,9 +316,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		case false:
 			if(acount == PLURAL)
 			{
-				char *target;
 				errno = 0;
-
 				if(mkdir(oparg->argv[loop_dst], 0755) == -1)
 				{
 					if((errno != EEXIST) && (errno != 0))
@@ -324,7 +328,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				}
 				else
 				{
-					target = get_dst_plus_srcname(oparg->argv[loop_dst], tmp_dst);
+					char *target = get_dst_plus_srcname(oparg->argv[loop_dst], tmp_dst);
 					strcpy(tmp_dst, target);
 					cpinfo->dst = get_dst_plus_srcname(tmp_src, target);
 					free(target);
@@ -338,15 +342,15 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 
 			if(link_flag == true)
 			{
-				file_list = link_copy(oparg, sdir, cpinfo, cpdd, file_list);
+				file_list = copy_arg_link(oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
 			{
-				file_list = file_copy(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
+				file_list = copy_arg_file(drive_list, tmp_src, tmp_dst, oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 			{
-				file_list = dir_copy(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
+				file_list = copy_arg_dir(tmp_src, tmp_dst, src_current_flag, drive_list, oparg, sdir, cpinfo, cpdd, file_list);
 			}
 			else
 			{
@@ -361,16 +365,16 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 	rdata->cpdd = cpdd;
 
 /*
-	THIS_DIR_FREE
+	FREE_THIS_DIR
 */
 	return rdata;
 }
 
 /*******************************************************************************
 *******************************************************************************/
-static inline VList * link_copy(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+static inline VList * copy_arg_link(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
 {
-	count_link_plus(cpinfo, cpdd);
+	count_plus_link(cpinfo, cpdd);
 	check_overwrite(oparg, sdir, cpinfo, cpdd);
 	file_list = append_list((void *)cpinfo, file_list);
 	return file_list;
@@ -378,10 +382,10 @@ static inline VList * link_copy(const OPArg *oparg, const SDir *sdir, CPInfo *cp
 
 /*******************************************************************************
 *******************************************************************************/
-static inline VList * file_copy(const VList *drive_list, const char tmp_src[], const char tmp_dst[], const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+static inline VList * copy_arg_file(const VList *drive_list, const char tmp_src[], const char tmp_dst[], const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
 {
-	count_file_plus(cpinfo, cpdd);
-	set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+	count_plus_file(cpinfo, cpdd);
+	check_set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
 	check_overwrite(oparg, sdir, cpinfo, cpdd);
 	file_list = append_list((void *)cpinfo, file_list);
 	return file_list;
@@ -389,7 +393,7 @@ static inline VList * file_copy(const VList *drive_list, const char tmp_src[], c
 
 /*******************************************************************************
 *******************************************************************************/
-static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
+static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, const _Bool src_current_flag, const VList *drive_list, const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd, VList *file_list)
 {
 	const char *s = tmp_src;
 	const char *d = tmp_dst;
@@ -408,15 +412,11 @@ static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _
 			s++;
 			d++;
 		}
-		else if(*s == '\0')
+		else if((*s == '\0') && (*d == G_DIR_SEPARATOR))
 		{
 			parent_flag = true;
 			break;
 		}
-		else if(*d == '\0')
-		{
-			break;
-		}
 		else 
 		{
 			break;
@@ -488,13 +488,13 @@ static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _
 	}
 	else
 	{
-		set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
+		check_set_same_or_different(drive_list, tmp_src, tmp_dst, oparg, cpinfo);
 
 		struct stat *stat_buf;
 
 		if(src_current_flag == false)
 		{
-			count_dire_plus(cpinfo, cpdd);
+			count_plus_dir(cpinfo, cpdd);
 			stat_buf = make_directory(oparg, cpinfo, cpdd);
 			file_list = append_list((void *)cpinfo, file_list);
 		}
@@ -521,7 +521,8 @@ static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _
 
 /*******************************************************************************
 *******************************************************************************/
-#define THIS_DIR_FREE \
+#define MAKE_THIS_DIR { this_dir = g_path_get_dirname(cpinfo->dst); }
+#define FREE_THIS_DIR \
 {\
 	if(this_dir != NULL)\
 	{\
@@ -530,11 +531,10 @@ static inline VList * dir_copy(const char *tmp_src, const char *tmp_dst, const _
 	}\
 }
 #define DO_NOT_OVERWRITE_FLAG { cpinfo->dst_para = SKIP; }
-#define MAKE_THIS_DIR         { this_dir = g_path_get_dirname(cpinfo->dst); }
 
 /*******************************************************************************
 *******************************************************************************/
-static inline void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+static void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
 	enum I_OverWrite_Type
 	{
@@ -543,20 +543,19 @@ static inline void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo
 		THIS_DIR_NO,
 	};
 
-	static enum I_OverWrite_Type iowt;
 	static _Bool info_flag;
+	static enum I_OverWrite_Type iowt;
 	static OPFlag I;
 	static OPFlag WMODE;
-	static char *this_dir;
 
 	if(info_flag == false)
 	{
+		info_flag = true;
 		iowt = INFO;
 
 		/* 変更される可能性があるオプションはローカル変数に入れておく */
 		I = oparg->I;
 		WMODE = oparg->WRITE_MODE;
-		info_flag = true;
 	}
 
 	gboolean fcheck  = g_file_test(cpinfo->dst, G_FILE_TEST_EXISTS);
@@ -565,7 +564,7 @@ static inline void check_overwrite(const OPArg *oparg, const SDir *sdir, CPInfo
 	/* true・false　→　stdbool */
 	if(fcheck == FALSE)
 	{
-		write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+		check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 	}
 	else
 	{
@@ -613,23 +612,26 @@ INPUT:
 					goto INPUT;
 				}
 
+				/* このフォルダで○○の時にフォルダパスを記憶しておく変数なのでstatic必須 */
+				static char *this_dir;
+
 				switch(stdin_buf[0])
 				{
 				case 'y':	/* 上書き */
-					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+					check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					break;
 
 				case 'a':	/* 全て上書き */
-					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+					check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					I = NOT;	/* 上書き確認モード無効 */
 					/* WMODE = OVERWRITE; */
 					/* ↑上書き確認モードでは最初からOVERWRITEになっている */
 					break;
 
 				case 'd':	/* このフォルダでのみ上書き */
-					write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+					check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					iowt = THIS_DIR_YES;
-					THIS_DIR_FREE
+					FREE_THIS_DIR
 					MAKE_THIS_DIR
 					break;
 
@@ -640,7 +642,7 @@ INPUT:
 				case 'o':	/* このフォルダでは上書きしない */
 					DO_NOT_OVERWRITE_FLAG
 					iowt = THIS_DIR_NO;
-					THIS_DIR_FREE
+					FREE_THIS_DIR
 					MAKE_THIS_DIR
 					break;
 
@@ -654,17 +656,17 @@ INPUT:
 
 			case THIS_DIR_YES:
 				{
-					_Bool b = this_dir_check(cpinfo, this_dir);
+					_Bool b = check_this_dir(cpinfo, this_dir);
 
 					if(b == true)
 					{
-						write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+						check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 					}
 					else
 					{
 						/* 再び上書き確認モードに */
 						iowt = INFO;
-						THIS_DIR_FREE
+						FREE_THIS_DIR
 						goto INPUT;
 					}
 				}
@@ -672,7 +674,7 @@ INPUT:
 
 			case THIS_DIR_NO:
 				{
-					_Bool b = this_dir_check(cpinfo, this_dir);
+					_Bool b = check_this_dir(cpinfo, this_dir);
 
 					if(b == true)
 					{
@@ -682,7 +684,7 @@ INPUT:
 					{
 						/* 再び上書き確認モードに */
 						iowt = INFO;
-						THIS_DIR_FREE
+						FREE_THIS_DIR
 						goto INPUT;
 					}
 				}
@@ -697,7 +699,7 @@ INPUT:
 			}
 			else
 			{
-				write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
+				check_write_file_or_create_link(oparg, sdir, cpinfo, cpdd);
 			}
 		}
 	}
@@ -705,7 +707,7 @@ INPUT:
 
 /*******************************************************************************
 *******************************************************************************/
-static inline void write_file_or_create_link(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
+static void check_write_file_or_create_link(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
 	if(cpinfo->src_type == REGULAR)
 	{
@@ -741,7 +743,7 @@ static inline void write_file_or_create_link(const OPArg *oparg, const SDir *sdi
 
 /*******************************************************************************
 *******************************************************************************/
-static inline _Bool this_dir_check(const CPInfo *cpinfo, const char *this_dir)
+static inline _Bool check_this_dir(const CPInfo *cpinfo, const char *this_dir)
 {
 	char *tmp = g_path_get_dirname(cpinfo->dst);
 	char *tmp_free = tmp;
@@ -838,14 +840,14 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 
 #define TYPE_IS_LINK \
 {\
-	count_link_plus(cpinfo, cpdd);\
+	count_plus_link(cpinfo, cpdd);\
 	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list((void *)cpinfo, file_list);\
 }
 
 #define TYPE_IS_FILE \
 {\
-	count_file_plus(cpinfo, cpdd);\
+	count_plus_file(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
 	check_overwrite(oparg, sdir, cpinfo, cpdd);\
 	file_list = append_list((void *)cpinfo, file_list);\
@@ -853,7 +855,7 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 
 #define TYPE_IS_DIR \
 {\
-	count_dire_plus(cpinfo, cpdd);\
+	count_plus_dir(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
 	struct stat *stat_buf = make_directory(oparg, cpinfo, cpdd);\
 	file_list = append_list((void *)cpinfo, file_list);\
@@ -886,7 +888,7 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 				int tdir = strlen(dst_dir);
 				int d_len = strlen(d_name);
 
-				CPInfo *cpinfo = cpinfo_malloc();
+				CPInfo *cpinfo = malloc_cpinfo();
 
 				/* +2は、 \0 と / の分 */
 				cpinfo->src = xmalloc(fdir + d_len + 2);
@@ -935,6 +937,7 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 				}
 			}
 		}
+
 		if(closedir(dp) == -1)
 		{
 			print_error("closedir", __FILE__, __LINE__, cpdd);
@@ -962,9 +965,9 @@ static inline void delete_last_slash(const int len, char tmp[])
 
 /******************************************************************************
 *******************************************************************************/
-static inline CPInfo * cpinfo_malloc(void)
+static inline CPInfo * malloc_cpinfo(void)
 {
-	CPInfo *cpinfo = xmalloc(sizeof(CPInfo));
+	CPInfo *cpinfo = xmalloc_inline(sizeof(CPInfo));
 	cpinfo->src = NULL;
 	cpinfo->dst = NULL;
 	cpinfo->dstfs = NULL;
@@ -1052,7 +1055,7 @@ BASENAME_END:
 
 /******************************************************************************
 *******************************************************************************/
-static inline void count_link_plus(CPInfo *cpinfo, CPDD *cpdd)
+static inline void count_plus_link(CPInfo *cpinfo, CPDD *cpdd)
 {
 	cpinfo->src_type = SYMBOLICLINK;
 	cpdd->link_count++;
@@ -1060,7 +1063,7 @@ static inline void count_link_plus(CPInfo *cpinfo, CPDD *cpdd)
 
 /******************************************************************************
 *******************************************************************************/
-static inline void count_file_plus(CPInfo *cpinfo, CPDD *cpdd)
+static inline void count_plus_file(CPInfo *cpinfo, CPDD *cpdd)
 {
 	cpinfo->src_type = REGULAR;
 	cpdd->file_count++;
@@ -1068,7 +1071,7 @@ static inline void count_file_plus(CPInfo *cpinfo, CPDD *cpdd)
 
 /******************************************************************************
 *******************************************************************************/
-static inline void count_dire_plus(CPInfo *cpinfo, CPDD *cpdd)
+static inline void count_plus_dir(CPInfo *cpinfo, CPDD *cpdd)
 {
 	cpinfo->src_type = DIRECTORY;
 	cpdd->dir_count++;
@@ -1096,7 +1099,7 @@ static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, const struct stat *
 
 	chown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
 
-	static struct utimbuf times;
+	struct utimbuf times;
 	times.actime  = stat_buf->st_atime;
 	times.modtime = stat_buf->st_mtime;
 
@@ -1169,7 +1172,7 @@ for(;;)\
 /******************************************************************************
  * ドライブが同一かどうか調べる
 *******************************************************************************/
-static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
+static inline void check_set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
 {
 	/*
 	 * キャストしないと警告が出る
@@ -1252,11 +1255,6 @@ DEV_CHECK_SKIP:
 
 	switch(oparg->THREAD_MODE)
 	{
-/*
-	case DRIVE_SAME:
-		cpinfo->copy_mode = SAME;
-		break;
-*/
 	case DRIVE_DIFFERENT:
 		cpinfo->copy_mode = DIFFERENT;
 		break;
