@@ -1,6 +1,6 @@
-#include "append_list.h" // inline
+#include "append_list.h"
 #include "struct_DPath.h"
-#include "xmalloc.h" // inline
+#include "xmalloc.h"
 
 #include <string.h>
 
