@@ -95,7 +95,7 @@ static int buffer_size_thread;
 static int ri;	// index number
 static int wi;	// index number
 static long psize;
-static _Bool verify;
+static _Bool verify_option;
 
 /* ※注意。グローバル変数。 */
 char *write_now;
@@ -163,7 +163,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	{
 		if(oparg->CHECK == V_FIVE)
 		{
-			verify = true;
+			verify_option = true;
 		}
 
 		verify_option_check = true;
@@ -184,39 +184,13 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				((tmp[0] == 'o') && (tmp[1] == 'c') && (tmp[2] == 'f') && (tmp[2] == 's') && (tmp[2] == '2'))
 			)
 			{
-				#ifdef _DEBUG_FLAG
-					puts("fallocate_support");
-					fflush(stdout);
-				#endif
-
 				fallocate_support = true;
 			}
 			else if((tmp[0] == 'x') && (tmp[1] == 'f') && (tmp[2] == 's'))
 			{
-				#ifdef _DEBUG_FLAG
-					puts("fallocate_support (xfs)");
-					fflush(stdout);
-				#endif
-
 				fallocate_support = true;
 				o_direct_write_flag = true;
 			}
-/*
-			else if
-			(
-				((tmp[0] == 'n') && (tmp[1] == 't') && (tmp[2] == 'f') && (tmp[3] == 's'))
-				||
-				((tmp[0] == 'f') && (tmp[1] == 'u') && (tmp[2] == 's') && (tmp[3] == 'e') && (tmp[4] == 'b') && (tmp[5] == 'l') && (tmp[6] == 'k'))
-			)
-			{
-				if(verify == true)
-				{
-					fprintf(stderr, "コピー先のファイルシステムがNTFSかつ、ベリファイオプションが有効です。\n");
-					fprintf(stderr, "終了します。\n");
-					exit(EXIT_FAILURE);
-				}
-			}
-*/
 		}
 
 		filesystem_check = true;
@@ -326,14 +300,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		}
 	}
 
-	#ifdef _DEBUG_FLAG
-		if(o_direct_open_dst == true)
-		{
-			puts("o_direct_open_dst = true");
-			fflush(stdout);
-		}
-	#endif
-
 	/*
 	 * ファイルシステムがfallocateをサポートしている場合、それを実行して領域を確保する。
 	 * 
@@ -343,11 +309,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	 */
 	if((src_size_local > 0) && (open_dst == true) && (fallocate_support == true))
 	{
-		#ifdef _DEBUG_FLAG
-			puts("fallocate");
-			fflush(stdout);
-		#endif
-
 		/* Ubuntu 11.04だとfallocateの第二引数は FALLOC_FL_KEEP_SIZE と FALLOC_FL_PUNCH_HOLE の二つ。linux/falloc.h のincludeが必要。 */
 		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
@@ -374,7 +335,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 		digest[0] = '\0';
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			md5_init(&state);
 		}
@@ -394,11 +355,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			}
 			else
 			{
-				#ifdef _DEBUG_FLAG
-					puts("mw_small_direct");
-					fflush(stdout);
-				#endif
-
 				mw_small_direct(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -410,11 +366,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			}
 			else
 			{
-				#ifdef _DEBUG_FLAG
-					puts("mw_thread_direct");
-					fflush(stdout);
-				#endif
-
 				mw_thread_direct(oparg, cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -426,11 +377,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			}
 			else
 			{
-				#ifdef _DEBUG_FLAG
-				puts("mw_big_direct");
-				fflush(stdout);
-				#endif
-
 				mw_big_direct(cpinfo, cpdd, &state, digest, &thread_argument, &t_verify);
 			}
 		}
@@ -469,22 +415,18 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	}
 */
 
-	if(open_src == true)
+	if((open_src == true) && (close(isrc) == -1))
 	{
-		if(close(isrc) == -1)
-		{
-			print_error("close", __FILE__, __LINE__, cpdd);
-		}
+		print_error("close", __FILE__, __LINE__, cpdd);
 	}
 
-	if(open_dst == true)
+	if((open_dst == true) && (close(idst) == -1))
 	{
-		if(close(idst) == -1)
-		{
-			print_error("close", __FILE__, __LINE__, cpdd);
-		}
+		print_error("close", __FILE__, __LINE__, cpdd);
 	}
 
+	write_now = NULL;
+
 	if(total_read_local > 0)
 	{
 		cpinfo->src_size = src_size_local;
@@ -507,8 +449,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		cpdd->total_error += total_write_error;
 	}
 
-	write_now = NULL;
-
 	if((open_src == true) && (open_dst == true) && (src_size_local <= total_write_local))
 	{
 		cpinfo->dst_para = WRITE;
@@ -540,7 +480,7 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 			print_error("madvise", __FILE__, __LINE__, cpdd);
 		}
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			thread_argument->state = state;
 			thread_argument->buffer = buf[0];
@@ -560,11 +500,12 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 				print_error("write", __FILE__, __LINE__, cpdd);
 				break;
 			}
+
 			tmp += written_size[0];
 			total_write_local += written_size[0];
 		}
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			pthread_join(*t_verify, NULL);
 
@@ -631,7 +572,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				thread_argument->state = state;
 				thread_argument->buffer = buf[0];
@@ -662,7 +603,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 				}
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				pthread_join(*t_verify, NULL);
 			}
@@ -676,7 +617,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 		}
 	}
 
-	if(verify == true)
+	if(verify_option == true)
 	{
 		MD5_FINISH
 	}
@@ -722,7 +663,7 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				thread_argument->state = state;
 				thread_argument->buffer = buf[0];
@@ -749,11 +690,12 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 
 					goto LOOP_END;
 				}
+
 				tmp += written_size[0];
 				total_write_local += written_size[0];
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				pthread_join(*t_verify, NULL);
 			}
@@ -772,7 +714,7 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 	}
 LOOP_END:
 ;
-	if(verify == true)
+	if(verify_option == true)
 	{
 		MD5_FINISH
 	}
@@ -840,7 +782,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 				print_error("madvise", __FILE__, __LINE__, cpdd);
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				thread_argument->state = state;
 				thread_argument->buffer = buf[0];
@@ -871,7 +813,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 				}
 			}
 
-			if(verify == true)
+			if(verify_option == true)
 			{
 				pthread_join(*t_verify, NULL);
 			}
@@ -884,7 +826,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 		}
 	}
 
-	if(verify == true)
+	if(verify_option == true)
 	{
 		MD5_FINISH
 	}
@@ -894,7 +836,6 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 *******************************************************************************/
 #define GET_BUFFER_SIZE \
 cpdd->thread_mode_count++;\
-\
 {\
 	VList *b_size_list = oparg->b_size_list;\
 	b_size_list = b_size_list->tail;\
@@ -951,7 +892,7 @@ static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 
 		pthread_create(&t_read, NULL, read_thread_func, (void *)&ri);
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			thread_argument->state = state;
 			thread_argument->buffer = buf[wi];
@@ -984,7 +925,7 @@ static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 			written_size[wi] = 0;
 		}
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			pthread_join(*t_verify, NULL);
 		}
@@ -1007,7 +948,7 @@ static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 		}
 	}
 
-	if(verify == true)
+	if(verify_option == true)
 	{
 		MD5_FINISH
 	}
@@ -1036,7 +977,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 
 		pthread_create(&t_read, NULL, read_thread_func, (void *)&ri);
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			thread_argument->state = state;
 			thread_argument->buffer = buf[wi];
@@ -1049,10 +990,12 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 		{
 			char *tmp = (char *)buf[wi];
 			off_t wtmp = next_write_size[wi];
+
 			if(wtmp < psize)
 			{
 				wtmp = psize;
 			}
+
 			const char * const endp = tmp + wtmp;
 
 			while(tmp < endp)
@@ -1085,7 +1028,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 			written_size[wi] = 0;
 		}
 
-		if(verify == true)
+		if(verify_option == true)
 		{
 			pthread_join(*t_verify, NULL);
 		}
@@ -1108,7 +1051,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 		}
 	}
 
-	if(verify == true)
+	if(verify_option == true)
 	{
 		MD5_FINISH
 	}
