@@ -1,10 +1,10 @@
 #include "analyze_argument.h"
 #include "check_target.h"
-#include "compare_verify_two.h"	// inline
+#include "compare_verify_two.h"
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
-#include "print_error.h"	// inline
+#include "print_error.h"
 #include "read_conf.h"
 #include "remove_source_rmdir.h"
 #include "set_signal.h"
@@ -69,11 +69,6 @@ int main(int argc, char **argv)
 	VList *drive_list = get_drive_list();
 	set_signal();
 
-	#ifdef _DEBUG_FLAG
-		puts("Debug modeで動作しています...");
-		fflush(stdout);
-	#endif
-
 	puts("コピーを開始します...");
 	fflush(stdout);
 
@@ -96,7 +91,10 @@ int main(int argc, char **argv)
 	}
 
 	/* ファイルとリンクはコピー直後に削除しているので、チェックするのはフォルダだけでよい。 */
-	if((oparg->M == MOVE) && (cpdd->dir_count > 0)) { delete_src(file_list, cpdd); }
+	if((oparg->M == MOVE) && (cpdd->dir_count > 0))
+	{
+		delete_src(file_list, cpdd);
+	}
 
 	puts("");
 
@@ -104,8 +102,14 @@ int main(int argc, char **argv)
 	{
 		printf("File   : %lld / %lld", cpdd->mk_file_count, cpdd->file_count);
 
-		if(cpdd->thread_mode_count > 0) { printf(" (Thread : %lld / %lld)\n", cpdd->thread_mode_count, cpdd->mk_file_count); }
-		else { puts(""); }
+		if(cpdd->thread_mode_count > 0)
+		{
+			printf(" (Thread : %lld / %lld)\n", cpdd->thread_mode_count, cpdd->mk_file_count);
+		}
+		else
+		{
+			puts("");
+		}
 	}
 
 	if(cpdd->link_count > 0)   { printf("Link   : %lld / %lld\n", cpdd->mk_link_count, cpdd->link_count); }
