@@ -1,10 +1,10 @@
 #define _GNU_SOURCE
 
-#include "print_error.h" // inline
+#include "print_error.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
 #include "verify_md5sum.h"
-#include "write_log_hash_check.h" // inline
+#include "write_log_hash_check.h"
 
 #include "md5.h"
 
@@ -25,31 +25,13 @@ static int fd;
 static int buffer_size_local;
 static long psize;
 static md5_state_t state;
-static md5_byte_t digest[16];
 static int read_size[BUF_NUM];
 static off_t total;
-static off_t static_dst_size;
 static int r_number;
 static int a_number;
-static _Bool lseek_err;
 static _Bool read_err;
 static _Bool read_finish;
 
-#define UNLINK_MISS_FILE \
-	print_error("NODATA", __FILE__, __LINE__, cpdd);\
-	write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, false);\
-	cpinfo->dst_para = DELETE;\
-\
-	errno = 0;\
-	if(unlink(cpinfo->dst) == -1)\
-	{\
-		if(errno != ENOENT)\
-		{\
-			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->dst);\
-		}\
-	}
-
 /* 関数プロトタイプ */
 void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
 static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
@@ -65,8 +47,6 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	read_size[0] = 0;
 	read_size[1] = 0;
 	total = 0;
-	static_dst_size = cpinfo->dst_size;
-	lseek_err = false;
 	read_err = false;
 	read_finish = false;
 
@@ -76,8 +56,8 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	}
 
 	_Bool open_flag;
-	errno = 0;
 
+	errno = 0;
 	if((fd = open(cpinfo->dst, O_NOATIME | O_NOFOLLOW | O_DIRECT | O_RDONLY)) == -1)
 	{
 		switch(errno)
@@ -112,12 +92,9 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		verify_md5sum(oparg, sdir, cpinfo, cpdd);
 	}
 
-	if(open_flag == true)
+	if((open_flag == true) && (close(fd) == -1))
 	{
-		if(close(fd) == -1)
-		{
-			print_error("close", __FILE__, __LINE__, cpdd);
-		}
+		print_error("close", __FILE__, __LINE__, cpdd);
 	}
 /*
 	free(buf[0]);
@@ -139,6 +116,18 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			fprintf(stderr, "`%s'\n", cpinfo->dst);
 			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+
+			if(buf[0] != NULL)
+			{
+				free(buf[0]);
+				buf[0] = NULL;
+			}
+
+			if(buf[1] != NULL)
+			{
+				free(buf[1]);
+				buf[1] = NULL;
+			}
 		}
 		else
 		{
@@ -179,16 +168,19 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			}
 		}
 
-		md5_finish(&state, digest);
-
-		static char hex_output[(16 * 2) + 1];
+		md5_byte_t digest[16];
+		char hex_output[(16 * 2) + 1];
 		hex_output[0] = '\0';
 
+		md5_finish(&state, digest);
+
 		for(int di = 0; di < 16; ++di)
 		{
 			sprintf(hex_output + di * 2, "%02x", digest[di]);
 		}
 
+		_Bool unlink_miss_file = false;
+
 		if(strcmp(cpinfo->src_md5, hex_output) == 0)
 		{
 			cpinfo->hash_check = true;
@@ -207,16 +199,31 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		}
 		else if(cpinfo->src_size > total)
 		{
+			unlink_miss_file = true;
 			fprintf(stderr, "ファイルの読み込みに失敗しました\n");
 			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
-			UNLINK_MISS_FILE
 		}
 		else
 		{
+			unlink_miss_file = true;
 			fprintf(stderr, "ハッシュ値が一致しませんでした\n");
 			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
-			UNLINK_MISS_FILE
 		}
+
+		if(unlink_miss_file == true)
+		{
+			print_error("NODATA", __FILE__, __LINE__, cpdd);
+			write_log_hash_check(cpinfo, cpinfo->src_md5, hex_output, sdir, cpdd, false);
+			cpinfo->dst_para = DELETE;
+
+			errno = 0;
+			if((unlink(cpinfo->dst) == -1) && (errno != ENOENT))
+			{
+				print_error("unlink", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->dst);
+			}
+		}
+
 		break;
 
 	case false:
